==> robomaker-0.26.0-sources.jar: software/amazon/awscdk/services/robomaker/CfnRobotProps.java <==
package software.amazon.awscdk.services.robomaker;

/**
 * Properties for defining a `AWS::RoboMaker::Robot`
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.15 (build e429c41)", date = "2019-03-20T12:56:16.722Z")
public interface CfnRobotProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::RoboMaker::Robot.Architecture`
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-architecture
     */
    java.lang.String getArchitecture();
    /**
     * `AWS::RoboMaker::Robot.Architecture`
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-architecture
     */
    void setArchitecture(final java.lang.String value);
    /**
     * `AWS::RoboMaker::Robot.GreengrassGroupId`
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-greengrassgroupid
     */
    java.lang.String getGreengrassGroupId();
    /**
     * `AWS::RoboMaker::Robot.GreengrassGroupId`
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-greengrassgroupid
     */
    void setGreengrassGroupId(final java.lang.String value);
    /**
     * `AWS::RoboMaker::Robot.Fleet`
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-fleet
     */
    java.lang.String getFleet();
    /**
     * `AWS::RoboMaker::Robot.Fleet`
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-fleet
     */
    void setFleet(final java.lang.String value);
    /**
     * `AWS::RoboMaker::Robot.Name`
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-name
     */
    java.lang.String getName();
    /**
     * `AWS::RoboMaker::Robot.Name`
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-name
     */
    void setName(final java.lang.String value);
    /**
     * `AWS::RoboMaker::Robot.Tags`
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-tags
     */
    com.fasterxml.jackson.databind.node.ObjectNode getTags();
    /**
     * `AWS::RoboMaker::Robot.Tags`
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-tags
     */
    void setTags(final com.fasterxml.jackson.databind.node.ObjectNode value);

    /**
     * @return a {@link Builder} of {@link CfnRobotProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnRobotProps}
     */
    final class Builder {
        private java.lang.String _architecture;
        private java.lang.String _greengrassGroupId;
        @javax.annotation.Nullable
        private java.lang.String _fleet;
        @javax.annotation.Nullable
        private java.lang.String _name;
        @javax.annotation.Nullable
        private com.fasterxml.jackson.databind.node.ObjectNode _tags;

        /**
         * Sets the value of Architecture
         * @param value `AWS::RoboMaker::Robot.Architecture`
         * @return {@code this}
         */
        public Builder withArchitecture(final java.lang.String value) {
            this._architecture = java.util.Objects.requireNonNull(value, "architecture is required");
            return this;
        }
        /**
         * Sets the value of GreengrassGroupId
         * @param value `AWS::RoboMaker::Robot.GreengrassGroupId`
         * @return {@code this}
         */
        public Builder withGreengrassGroupId(final java.lang.String value) {
            this._greengrassGroupId = java.util.Objects.requireNonNull(value, "greengrassGroupId is required");
            return this;
        }
        /**
         * Sets the value of Fleet
         * @param value `AWS::RoboMaker::Robot.Fleet`
         * @return {@code this}
         */
        public Builder withFleet(@javax.annotation.Nullable final java.lang.String value) {
            this._fleet = value;
            return this;
        }
        /**
         * Sets the value of Name
         * @param value `AWS::RoboMaker::Robot.Name`
         * @return {@code this}
         */
        public Builder withName(@javax.annotation.Nullable final java.lang.String value) {
            this._name = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value `AWS::RoboMaker::Robot.Tags`
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final com.fasterxml.jackson.databind.node.ObjectNode value) {
            this._tags = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnRobotProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public CfnRobotProps build() {
            return new CfnRobotProps() {
                private java.lang.String $architecture = java.util.Objects.requireNonNull(_architecture, "architecture is required");
                private java.lang.String $greengrassGroupId = java.util.Objects.requireNonNull(_greengrassGroupId, "greengrassGroupId is required");
                @javax.annotation.Nullable
                private java.lang.String $fleet = _fleet;
                @javax.annotation.Nullable
                private java.lang.String $name = _name;
                @javax.annotation.Nullable
                private com.fasterxml.jackson.databind.node.ObjectNode $tags = _tags;

                @Override
                public java.lang.String getArchitecture() {
                    return this.$architecture;
                }

                @Override
                public void setArchitecture(final java.lang.String value) {
                    this.$architecture = java.util.Objects.requireNonNull(value, "architecture is required");
                }

                @Override
                public java.lang.String getGreengrassGroupId() {
                    return this.$greengrassGroupId;
                }

                @Override
                public void setGreengrassGroupId(final java.lang.String value) {
                    this.$greengrassGroupId = java.util.Objects.requireNonNull(value, "greengrassGroupId is required");
                }

                @Override
                public java.lang.String getFleet() {
                    return this.$fleet;
                }

                @Override
                public void setFleet(@javax.annotation.Nullable final java.lang.String value) {
                    this.$fleet = value;
                }

                @Override
                public java.lang.String getName() {
                    return this.$name;
                }

                @Override
                public void setName(@javax.annotation.Nullable final java.lang.String value) {
                    this.$name = value;
                }

                @Override
                public com.fasterxml.jackson.databind.node.ObjectNode getTags() {
                    return this.$tags;
                }

                @Override
                public void setTags(@javax.annotation.Nullable final com.fasterxml.jackson.databind.node.ObjectNode value) {
                    this.$tags = value;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.robomaker.CfnRobotProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::RoboMaker::Robot.Architecture`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-architecture
         */
        @Override
        public java.lang.String getArchitecture() {
            return this.jsiiGet("architecture", java.lang.String.class);
        }

        /**
         * `AWS::RoboMaker::Robot.Architecture`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-architecture
         */
        @Override
        public void setArchitecture(final java.lang.String value) {
            this.jsiiSet("architecture", java.util.Objects.requireNonNull(value, "architecture is required"));
        }

        /**
         * `AWS::RoboMaker::Robot.GreengrassGroupId`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-greengrassgroupid
         */
        @Override
        public java.lang.String getGreengrassGroupId() {
            return this.jsiiGet("greengrassGroupId", java.lang.String.class);
        }

        /**
         * `AWS::RoboMaker::Robot.GreengrassGroupId`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-greengrassgroupid
         */
        @Override
        public void setGreengrassGroupId(final java.lang.String value) {
            this.jsiiSet("greengrassGroupId", java.util.Objects.requireNonNull(value, "greengrassGroupId is required"));
        }

        /**
         * `AWS::RoboMaker::Robot.Fleet`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-fleet
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.String getFleet() {
            return this.jsiiGet("fleet", java.lang.String.class);
        }

        /**
         * `AWS::RoboMaker::Robot.Fleet`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-fleet
         */
        @Override
        public void setFleet(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("fleet", value);
        }

        /**
         * `AWS::RoboMaker::Robot.Name`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-name
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.String getName() {
            return this.jsiiGet("name", java.lang.String.class);
        }

        /**
         * `AWS::RoboMaker::Robot.Name`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-name
         */
        @Override
        public void setName(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("name", value);
        }

        /**
         * `AWS::RoboMaker::Robot.Tags`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-tags
         */
        @Override
        @javax.annotation.Nullable
        public com.fasterxml.jackson.databind.node.ObjectNode getTags() {
            return this.jsiiGet("tags", com.fasterxml.jackson.databind.node.ObjectNode.class);
        }

        /**
         * `AWS::RoboMaker::Robot.Tags`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-tags
         */
        @Override
        public void setTags(@javax.annotation.Nullable final com.fasterxml.jackson.databind.node.ObjectNode value) {
            this.jsiiSet("tags", value);
        }
    }
}

==> robomaker-0.27.0-sources.jar: software/amazon/awscdk/services/robomaker/CfnRobotProps.java <==
package software.amazon.awscdk.services.robomaker;

/**
 * Properties for defining a `AWS::RoboMaker::Robot`
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.8.2 (build e9eb3c9)", date = "2019-03-28T21:34:14.464Z")
public interface CfnRobotProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::RoboMaker::Robot.Architecture`
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-architecture
     */
    java.lang.String getArchitecture();
    /**
     * `AWS::RoboMaker::Robot.GreengrassGroupId`
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-greengrassgroupid
     */
    java.lang.String getGreengrassGroupId();
    /**
     * `AWS::RoboMaker::Robot.Fleet`
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-fleet
     */
    java.lang.String getFleet();
    /**
     * `AWS::RoboMaker::Robot.Name`
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-name
     */
    java.lang.String getName();
    /**
     * `AWS::RoboMaker::Robot.Tags`
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-tags
     */
    com.fasterxml.jackson.databind.node.ObjectNode getTags();

    /**
     * @return a {@link Builder} of {@link CfnRobotProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnRobotProps}
     */
    final class Builder {
        private java.lang.String _architecture;
        private java.lang.String _greengrassGroupId;
        @javax.annotation.Nullable
        private java.lang.String _fleet;
        @javax.annotation.Nullable
        private java.lang.String _name;
        @javax.annotation.Nullable
        private com.fasterxml.jackson.databind.node.ObjectNode _tags;

        /**
         * Sets the value of Architecture
         * @param value `AWS::RoboMaker::Robot.Architecture`
         * @return {@code this}
         */
        public Builder withArchitecture(final java.lang.String value) {
            this._architecture = java.util.Objects.requireNonNull(value, "architecture is required");
            return this;
        }
        /**
         * Sets the value of GreengrassGroupId
         * @param value `AWS::RoboMaker::Robot.GreengrassGroupId`
         * @return {@code this}
         */
        public Builder withGreengrassGroupId(final java.lang.String value) {
            this._greengrassGroupId = java.util.Objects.requireNonNull(value, "greengrassGroupId is required");
            return this;
        }
        /**
         * Sets the value of Fleet
         * @param value `AWS::RoboMaker::Robot.Fleet`
         * @return {@code this}
         */
        public Builder withFleet(@javax.annotation.Nullable final java.lang.String value) {
            this._fleet = value;
            return this;
        }
        /**
         * Sets the value of Name
         * @param value `AWS::RoboMaker::Robot.Name`
         * @return {@code this}
         */
        public Builder withName(@javax.annotation.Nullable final java.lang.String value) {
            this._name = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value `AWS::RoboMaker::Robot.Tags`
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final com.fasterxml.jackson.databind.node.ObjectNode value) {
            this._tags = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnRobotProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public CfnRobotProps build() {
            return new CfnRobotProps() {
                private final java.lang.String $architecture = java.util.Objects.requireNonNull(_architecture, "architecture is required");
                private final java.lang.String $greengrassGroupId = java.util.Objects.requireNonNull(_greengrassGroupId, "greengrassGroupId is required");
                @javax.annotation.Nullable
                private final java.lang.String $fleet = _fleet;
                @javax.annotation.Nullable
                private final java.lang.String $name = _name;
                @javax.annotation.Nullable
                private final com.fasterxml.jackson.databind.node.ObjectNode $tags = _tags;

                @Override
                public java.lang.String getArchitecture() {
                    return this.$architecture;
                }

                @Override
                public java.lang.String getGreengrassGroupId() {
                    return this.$greengrassGroupId;
                }

                @Override
                public java.lang.String getFleet() {
                    return this.$fleet;
                }

                @Override
                public java.lang.String getName() {
                    return this.$name;
                }

                @Override
                public com.fasterxml.jackson.databind.node.ObjectNode getTags() {
                    return this.$tags;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("architecture", om.valueToTree(this.getArchitecture()));
                    obj.set("greengrassGroupId", om.valueToTree(this.getGreengrassGroupId()));
                    obj.set("fleet", om.valueToTree(this.getFleet()));
                    obj.set("name", om.valueToTree(this.getName()));
                    obj.set("tags", om.valueToTree(this.getTags()));
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.robomaker.CfnRobotProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::RoboMaker::Robot.Architecture`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-architecture
         */
        @Override
        public java.lang.String getArchitecture() {
            return this.jsiiGet("architecture", java.lang.String.class);
        }

        /**
         * `AWS::RoboMaker::Robot.GreengrassGroupId`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-greengrassgroupid
         */
        @Override
        public java.lang.String getGreengrassGroupId() {
            return this.jsiiGet("greengrassGroupId", java.lang.String.class);
        }

        /**
         * `AWS::RoboMaker::Robot.Fleet`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-fleet
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.String getFleet() {
            return this.jsiiGet("fleet", java.lang.String.class);
        }

        /**
         * `AWS::RoboMaker::Robot.Name`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-name
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.String getName() {
            return this.jsiiGet("name", java.lang.String.class);
        }

        /**
         * `AWS::RoboMaker::Robot.Tags`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robot.html#cfn-robomaker-robot-tags
         */
        @Override
        @javax.annotation.Nullable
        public com.fasterxml.jackson.databind.node.ObjectNode getTags() {
            return this.jsiiGet("tags", com.fasterxml.jackson.databind.node.ObjectNode.class);
        }
    }
}
